==> gf-restadmin-connector-4.0-b33-sources.jar: org/glassfish/admin/restconnector/Constants.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.admin.restconnector;

/**
 * @author Sanjeeb.Sahoo@Sun.COM
 */
public final class Constants {
    private Constants(){}

    public static final String REST_ADMIN_ADAPTER      = "RestAdminAdapter";
    public static final String REST_MANAGEMENT_ADAPTER = "RestManagementAdapter";
    public static final String REST_MONITORING_ADAPTER = "RestMonitoringAdapter";
    public static final String REST_ADMIN_CONTEXT_ROOT = "/admin";
    public static final String REST_MANAGEMENT_CONTEXT_ROOT = "/management";
    public static final String REST_MONITORING_CONTEXT_ROOT = "/monitoring";
}

==> gf-restadmin-connector-5.0.1-sources.jar: org/glassfish/admin/restconnector/Constants.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.admin.restconnector;

/**
 * @author Sanjeeb.Sahoo@Sun.COM
 */
public final class Constants {
    private Constants(){}

    public static final String REST_ADMIN_ADAPTER      = "RestAdminAdapter";
    public static final String REST_MANAGEMENT_ADAPTER = "RestManagementAdapter";
    public static final String REST_MONITORING_ADAPTER = "RestMonitoringAdapter";
    public static final String REST_COMMAND_ADAPTER = "RestCommandAdapter";
    public static final String REST_ADMIN_CONTEXT_ROOT = "/admin";
    public static final String REST_MANAGEMENT_CONTEXT_ROOT = "/management";
    public static final String REST_MONITORING_CONTEXT_ROOT = "/monitoring";
    public static final String REST_COMMAND_CONTEXT_ROOT = "/command";
}
